function [l1,v1,ammv,x1]=interno6b(X,tol)
% Realizza il ciclo iterativo interno nel caso del sistema a 6 equazioni. Riceve i valori 
% di x e la tolleranza prefissata, restituendo il numero totale di moli prtesenti nelle 
% fasi liquida e vapore, oltre al vettore soluzione che rappresenta le quantit delle
% singole componenti il sistema suddivise tra le due fasi. In particolare ammv (cio x1(4))
% viene utilizzata per ricalcolare il valore di X nell'iterazione esterna.

l0=5;
v0=9-X-l0;
b6=vect6(X);
A06=matrix6(l0,v0);
x0=A06\b6;
% Si fissano i valori iniziali di l e v, si crea un prima matrice A06 e si risolve 
% il sistema una prima volta, trovando x0.   
l1=x0(1)+x0(3);
v1=x0(2)+x0(4)+x0(5)+x0(6);
A16=matrix6(l1,v1);
x1=A16\b6;
ammv=x1(4);
% Viene assegnata ad ammv una componente del vettore soluzione, corrispondente al numero
% di moli di ammoniaca presenti in fase vapore.
devx=norm(x1-x0)/norm(x0);
% La matrice del sistema viene aggiornata (A16) in base ai nuovi valori di l e v (l1,v1);
% si calcola una nuova soluzione x1 le cui compnenti vengono assegnate alle rispettive
% variabili. Viene calcolato lo scarto relativo tra le due soluzioni, sul quale si basa
% il test di tolleranza.
count=1;
[ban(count),mag(count)]=perturbazione(A06,A16,b6,b6);
% Vengono costituiti due vettori per registrare l'andamento della condizione del lemma di 
% perturbazione di Banach e della maggiorazione che ne deriva sullo scarto relativo tra
% due soluzioni successive. Si ricorre all'uso della funzione perturbazione. Il termine 
% noto b6 non viene modificato in questo ciclo interno in quanto il valore di X, da cui
% dipende, resta invariato.
A06=A16;
% La matrice "nuova" diventa la matrice "vecchia" del successivo passo iterativo.
while devx>=tol    % Test di tolleranza
   x0=x1;
   % La soluzione trovata diventa il punto di partenza in questo passo iterativo.
   l1=x0(1)+x0(3);
   v1=x0(2)+x0(4)+x0(5)+x0(6);
   A16=matrix6(l1,v1);
   % Aggiornamento dei valori di l,v e della matrice.
   x1=A16\b6;
   ammv=x1(4);
   % Calcolo della nuova soluzione ed aggiornamento di ammv.
   devx=norm(x1-x0)/norm(x0);
   count=count+1;
   [ban(count),mag(count)]=perturbazione(A06,A16,b6,b6);
   % Aggiunta dei nuovi elementi ai vettori relativi alle perturbazioni. Il vettore b6
   % rimane sempre invariato.
   A06=A16;
end
disp(x1);
disp(ban');
disp(mag');
% Con queste istruzioni si visualizzano i risultati di ogni iterazione interna.
plot(mag);